#include <LiquidCrystal.h>
#include <Servo.h>

#define NUM_TO_AVERAGE 500   // avergae constant used to average readings

Servo myservo;              //  create servo object to control servo

LiquidCrystal lcd(12,11,5,4,3,2);

long a0_value, a1_value;    // initialize voltage variables
float a0_voltage, a1_voltage, volt_diff;
int pos;                    // initialize servo motor position variable
int mode_flag = 0;          // identify the system 0: manual 1: automatic 
int input_pos = 0;          // inputposition

void setup()
{
  lcd.begin(16, 2);
  lcd.clear();
  lcd.print("Servo Controller");
  delay(2000);
  lcd.clear();
  myservo.attach(10);       //  attaches servo object to pin 10
  Serial.begin(9600);
  myservo.write(0);         //  initialize servo to 0 position
  pinMode(9, INPUT);        //  backup input pin, currently not used in this application
}

void loop()
{
  a0_value = 0;
  a1_value = 0;
  for(int i=0; i<NUM_TO_AVERAGE; i++){
    a0_value += analogRead(0);
    a1_value += analogRead(1);
  }

  a0_voltage = a0_value / NUM_TO_AVERAGE * (5.0/1023);  // convert steps to volts
  a1_voltage = a1_value / NUM_TO_AVERAGE  * (5.0/1023); // convert steps to volts

  volt_diff  = a1_voltage - a0_voltage;                 // calculate voltage difference
  
  if (Serial.available() > 0) {
    // get input position
    for (int x = 0; x < 3; x++){
      switch (x) {
        case 0:
          input_pos = Serial.parseInt();          // read the input position specified by the user
          break;
        case 1:
          mode_flag = Serial.parseInt();          // read the input mode change
          break;
        case 2:
          for (int y = Serial.available(); y == 0; y--){
              Serial.read();                    // clear out any residual junk
            }
          break;
      }
    }
  }
  if (mode_flag == 1) {
     input_pos = volt_diff / 5.0 * 180;       //  calculate pos according to voltage reading
  }
    
  pos = input_pos;                  //assign input position to pos variable
  myservo.write(pos);                       //  tell servo motor to turn "pos" degrees

  lcd.setCursor(0,0);
  lcd.print("Volt: ");
  lcd.print(volt_diff, 3);

 
  lcd.setCursor(0,1);
  lcd.print("Pos: ");
  lcd.print(pos);
  
  Serial.print(volt_diff);   // register the voltage to the serial register
  Serial.print("\t");
  Serial.print(pos);
  Serial.print("\t");
  Serial.println(input_pos);
}
